@@ -1,7 +1,6 @@
 __author__ = 'v.denisov'
 from rais.client_reguest import ClientReguest as cr
 from rais.parameter_initialization import ParameterInitialization as pi
-#from rais.config_host import ConfigHost as config
 
 class SessionHelper:
 
@@ -13,6 +12,20 @@ class SessionHelper:
 
     @classmethod
     def login(self, username, password, profiles_cookie, language):
+        """
+        Выполняет логин к rais и сохраняет полученные cooke
+
+        :param username:
+        :type username:
+        :param password:
+        :type password:
+        :param profiles_cookie:
+        :type profiles_cookie:
+        :param language:
+        :type language:
+        :return:
+        :rtype:
+        """
         response = cr.get(url=pi.get_url_host()+'/get_rsid')
         for cookie in response.cookies:
             if cookie.name in 'rsid':
@@ -28,7 +41,7 @@ class SessionHelper:
             "lang" : language
         }
         response_login = cr.post(url=pi.get_url_host() + '/interface/orange/user/login', params=params)
-        print('response_login=', response_login.json())
+        return response_login
 
 
 
